@@ -273,7 +273,7 @@ static void parse_filetime( const char *str, guint64 *ft )
 
     while ( *p == ' ' || *p == '\t' ) p++;
 
-    tm.tm_year = strtol( p, &end, 10 );
+    tm.tm_year = strtol( p, &end, 10 ) - 1900;
     if (*end != '/') return;
     p = end + 1;
 
@@ -313,12 +313,14 @@ static void read_properties_from_data( LibmsiOLEVariant *prop, const uint8_t *da
     LibmsiOLEVariant *property;
     uint32_t idofs, len;
     char *str = NULL;
+    gboolean valid;
 
     idofs = 8;
 
     /* now set all the properties */
     for( i = 0; i < cProperties; i++ )
     {
+        valid = TRUE;
         int propid = read_dword(data, &idofs);
         unsigned dwOffset = read_dword(data, &idofs);
         int proptype;
@@ -351,7 +353,6 @@ static void read_properties_from_data( LibmsiOLEVariant *prop, const uint8_t *da
             break;
         }
 
-        property->vt = proptype;
         switch(proptype)
         {
         case OLEVT_I2:
@@ -362,6 +363,7 @@ static void read_properties_from_data( LibmsiOLEVariant *prop, const uint8_t *da
             if( dwOffset + 8 > sz )
             {
                 g_critical("not enough data for type %d %d \n", dwOffset, sz);
+                valid = FALSE;
                 break;
             }
             property->filetime = read_dword(data, &dwOffset);
@@ -372,6 +374,7 @@ static void read_properties_from_data( LibmsiOLEVariant *prop, const uint8_t *da
             if( dwOffset + len > sz )
             {
                 g_critical("not enough data for type %d %d %d \n", dwOffset, len, sz);
+                valid = FALSE;
                 break;
             }
             str = msi_alloc( len );
@@ -382,6 +385,10 @@ static void read_properties_from_data( LibmsiOLEVariant *prop, const uint8_t *da
             g_warn_if_reached ();
         }
 
+        if (valid == FALSE) {
+            break;
+        }
+
         /* check the type is the same as we expect */
         if( type == OLEVT_LPSTR && proptype == OLEVT_LPSTR)
            property->strval = str;
@@ -401,6 +408,9 @@ static void read_properties_from_data( LibmsiOLEVariant *prop, const uint8_t *da
             g_critical("invalid type \n");
             break;
         }
+
+        /* Now we now the type is valid, store it */
+        property->vt = proptype;
     }
 }
 
