@@ -669,7 +669,7 @@ static unsigned get_tablecolumns( LibmsiDatabase *db, const char *szTableName, L
     /* Note: _Columns table doesn't have non-persistent data */
 
     /* if maxcount is non-zero, assume it's exactly right for this table */
-    memset( colinfo, 0, maxcount * sizeof(*colinfo) );
+    if (colinfo) memset( colinfo, 0, maxcount * sizeof(*colinfo) );
     count = table->row_count;
     for (i = 0; i < count; i++)
     {
@@ -682,7 +682,7 @@ static unsigned get_tablecolumns( LibmsiDatabase *db, const char *szTableName, L
             /* check the column number is in range */
             if (col < 1 || col > maxcount)
             {
-                g_critical("column %d out of range\n", col);
+                g_critical("column %d out of range (maxcount: %d)\n", col, maxcount);
                 continue;
             }
             /* check if this column was already set */
@@ -1813,8 +1813,10 @@ static unsigned table_view_remove_column(LibmsiView *view, const char *table, un
     libmsi_record_set_int(rec, 2, number);
 
     r = table_view_create(tv->db, szColumns, &columns);
-    if (r != LIBMSI_RESULT_SUCCESS)
+    if (r != LIBMSI_RESULT_SUCCESS) {
+        g_object_unref(rec);
         return r;
+    }
 
     r = msi_table_find_row((LibmsiTableView *)columns, rec, &row, NULL);
     if (r != LIBMSI_RESULT_SUCCESS)
@@ -1935,8 +1937,10 @@ static unsigned table_view_drop(LibmsiView *view)
     libmsi_record_set_string(rec, 1, tv->name);
 
     r = table_view_create(tv->db, szTables, &tables);
-    if (r != LIBMSI_RESULT_SUCCESS)
+    if (r != LIBMSI_RESULT_SUCCESS) {
+        g_object_unref(rec);
         return r;
+    }
 
     r = msi_table_find_row((LibmsiTableView *)tables, rec, &row, NULL);
     if (r != LIBMSI_RESULT_SUCCESS)
